BlogsStrings class
Constructors
- BlogsStrings({String pageTitle = 'Blog', String searchHint = 'Search blogs...', String noBlogsAvailable = 'No blogs available', String errorLoadingBlogs = 'Error loading blogs', String? noSearchResults, String readMore = 'Read More →', String? pageOf, String copyLink = 'Copy Link', String linkCopied = 'Link copied to clipboard!', String viewImage = 'View Image', String failedToLoadImage = 'Failed to load image', String tryAgain = 'Try Again'})
-
const
Properties
- copyLink → String
-
final
- errorLoadingBlogs → String
-
final
- failedToLoadImage → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- linkCopied → String
-
final
- noBlogsAvailable → String
-
final
- noSearchResults → String?
-
final
- pageOf → String?
-
final
- pageTitle → String
-
final
- readMore → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchHint → String
-
final
-
final
-
final
- tryAgain → String
-
final
- viewImage → String
-
final
Methods
-
merge(
BlogsStrings? other) → BlogsStrings -
noSearchResultsFor(
String query) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pageLabel(
int current, int last) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited